#!/usr/bin/env python3

import evdev
import select
import sys


VOLUME_DOWN = 114
VOLUME_UP = 115
POWER = 116

# Obtain objects for the input devices.
devices = []

for path in evdev.list_devices():
    device = evdev.InputDevice(path)
    if evdev.ecodes.EV_KEY in device.capabilities():
        devices.append(device)

if not devices:
    sys.stderr.write('Failed to find any key input devices.\n')
    sys.exit(1)

fds = dict([(device.fd, device) for device in devices])

while True:

    # Wait for an event.
    r, w, x = select.select(fds.keys(), [], [])

    # Read the events for the device.
    for fd in r:
        device = fds[fd]

        for event in device.read():

            pressed = {0: "released", 1: "pressed"}[event.value]

            if event.code == VOLUME_UP:
                print("volume up", pressed)
            elif event.code == VOLUME_DOWN:
                print("volume down", pressed)
            elif event.code == POWER:
                print("power", pressed)
